Package: cSEM
Title: Composite-Based Structural Equation Modeling
Version: 0.6.1
Date: 2025-05-15
Authors@R: c(person(given = "Manuel E.", family = "Rademaker",
                    role  = c("aut"),
                    email = "manuel-rademaker@outlook.de",
                    comment = c(ORCID = "0000-0002-8902-3561")),
             person(given = "Florian", family = "Schuberth",
                    role  = c("aut", "cre"),
                    email = "f.schuberth@utwente.nl",
                    comment = c(ORCID = "0000-0002-2110-9086")),
             person(given = "Tamara", family = "Schamberger",
                    role  = c("ctb"),
                    email = "tamara.schamberger@uni-wuerzburg.de",
                    comment = c(ORCID = "0000-0002-7845-784X")),
             person(given = "Michael", family = "Klesel",
                    role  = c("ctb"),
                    email = "",
                    comment = c(ORCID = "0000-0002-2884-1819")),
             person(given = "Huu Phuc", family = "Nguyen",
                    role  = c("ctb"),
                    email = "",
                    comment = c(ORCID = "0009-0000-9344-7132")),       
             person(given = "Theo K.", family = "Dijkstra",
                    role  = c("ctb"),
                    email = ""),
             person(given = "Jörg", family = "Henseler",
                    role  = c("ctb"),
                    email = "",
                    comment = c(ORCID = "0000-0002-9736-3048")))
Maintainer: Florian Schuberth <f.schuberth@utwente.nl>
Depends: R (>= 3.5.0)
Description: Estimate, assess, test, and study linear, nonlinear, hierarchical 
  and multigroup structural equation models using composite-based approaches 
  and procedures, including estimation techniques such as partial least squares 
  path modeling (PLS-PM) and its derivatives (PLSc, ordPLSc, robustPLSc), 
  generalized structured component analysis (GSCA), generalized structured 
  component analysis with uniqueness terms (GSCAm), generalized canonical 
  correlation analysis (GCCA), principal component analysis (PCA), 
  factor score regression (FSR) using sum score, regression or 
  Bartlett scores (including bias correction using Croon’s approach), 
  as well as several tests and typical postestimation procedures 
  (e.g., verify admissibility of the estimates, assess the model fit, 
  test the model fit etc.).
BugReports: https://github.com/FloSchuberth/cSEM/issues/
URL: https://github.com/FloSchuberth/cSEM/,
        https://floschuberth.github.io/cSEM/
License: GPL-3
Encoding: UTF-8
NeedsCompilation: yes
LazyData: true
Imports: alabama, cli, crayon, expm (>= 0.999-5), future.apply, future,
        lifecycle, lavaan, magrittr, MASS, Matrix, matrixcalc,
        matrixStats, polycor, progressr, psych, purrr, Rdpack, rlang,
        stats, symmoments, TruncatedNormal, utils
RdMacros: Rdpack, lifecycle
RoxygenNote: 7.3.2
Suggests: DiagrammeR, DiagrammeRsvg, dplyr, tidyr, knitr, nnls,
        prettydoc, plotly, rsvg, rmarkdown, rootSolve, listviewer,
        testthat (>= 3.0.0), ggplot2, openxlsx, graphics, spelling
Config/testthat/edition: 3
VignetteBuilder: knitr
Language: en-US
Packaged: 2025-05-15 14:33:52 UTC; SchuberthF
Author: Manuel E. Rademaker [aut] (ORCID:
    <https://orcid.org/0000-0002-8902-3561>),
  Florian Schuberth [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-2110-9086>),
  Tamara Schamberger [ctb] (ORCID:
    <https://orcid.org/0000-0002-7845-784X>),
  Michael Klesel [ctb] (ORCID: <https://orcid.org/0000-0002-2884-1819>),
  Huu Phuc Nguyen [ctb] (ORCID: <https://orcid.org/0009-0000-9344-7132>),
  Theo K. Dijkstra [ctb],
  Jörg Henseler [ctb] (ORCID: <https://orcid.org/0000-0002-9736-3048>)
Repository: CRAN
Date/Publication: 2025-05-16 09:40:14 UTC
Built: R 4.6.0; ; 2026-04-28 01:41:03 UTC; unix
