## ----eval=FALSE---------------------------------------------------------------
# assess(
#   .object              = NULL,
#   .only_common_factors = TRUE,
#   .quality_criterion   = c("all", "aic", "aicc", "aicu", "bic", "fpe", "gm", "hq",
#                            "hqc", "mallows_cp", "ave",
#                            "rho_C", "rho_C_mm", "rho_C_weighted",
#                            "rho_C_weighted_mm", "dg", "dl", "dml", "df",
#                            "effects", "f2", "fl_criterion", "chi_square", "chi_square_df",
#                            "cfi", "gfi", "ifi", "nfi", "nnfi",
#                            "reliability",
#                            "rmsea", "rms_theta", "srmr",
#                            "gof", "htmt", "r2", "r2_adj",
#                            "rho_T", "rho_T_weighted", "vif",
#                            "vifmodeB"),
#   ...
# )

